@@ -1031,6 +1031,12 @@ rsvg_handle_load_extern (RsvgHandle *handle, const char *uri)
     return res;
 }
 
+gboolean
+rsvg_handle_keep_image_data (RsvgHandle *handle)
+{
+    return (handle->priv->flags & RSVG_HANDLE_FLAG_KEEP_IMAGE_DATA) != 0;
+}
+
 static RsvgDrawingCtx *
 rsvg_handle_create_drawing_ctx(RsvgHandle *handle,
                                cairo_t *cr,
@@ -1096,21 +1102,21 @@ rsvg_handle_render_cairo_sub (RsvgHandle * handle, cairo_t * cr, const char *id)
     if (dimensions.width == 0 || dimensions.height == 0)
         return FALSE;
 
+    cairo_save (cr);
+
     draw = rsvg_handle_create_drawing_ctx (handle, cr, &dimensions);
 
     if (drawsub != NULL) {
         rsvg_drawing_ctx_add_node_and_ancestors_to_stack (draw, drawsub);
     }
 
-    cairo_save (cr);
-
     rsvg_tree_cascade (handle->priv->tree);
     res = rsvg_drawing_ctx_draw_node_from_stack (draw, handle->priv->tree);
 
-    cairo_restore (cr);
-
     rsvg_drawing_ctx_free (draw);
 
+    cairo_restore (cr);
+
     return res;
 }
 
@@ -1719,86 +1725,6 @@ _rsvg_handle_acquire_stream (RsvgHandle *handle,
     return stream;
 }
 
-cairo_surface_t *
-rsvg_cairo_surface_new_from_href (RsvgHandle *handle,
-                                  const char *href,
-                                  GError **error)
-{
-    char *data;
-    gsize data_len;
-    char *mime_type = NULL;
-    GdkPixbufLoader *loader = NULL;
-    GdkPixbuf *pixbuf = NULL;
-    cairo_surface_t *surface = NULL;
-
-    data = _rsvg_handle_acquire_data (handle, href, &mime_type, &data_len, error);
-    if (data == NULL)
-        return NULL;
-
-    if (mime_type) {
-        loader = gdk_pixbuf_loader_new_with_mime_type (mime_type, error);
-    } else {
-        loader = gdk_pixbuf_loader_new ();
-    }
-
-    if (loader == NULL)
-        goto out;
-
-    if (!gdk_pixbuf_loader_write (loader, (guchar *) data, data_len, error)) {
-        gdk_pixbuf_loader_close (loader, NULL);
-        goto out;
-    }
-
-    if (!gdk_pixbuf_loader_close (loader, error))
-        goto out;
-
-    pixbuf = gdk_pixbuf_loader_get_pixbuf (loader);
-
-    if (!pixbuf) {
-        g_set_error (error,
-                     GDK_PIXBUF_ERROR,
-                     GDK_PIXBUF_ERROR_FAILED,
-                      _("Failed to load image '%s': reason not known, probably a corrupt image file"),
-                      href);
-        goto out;
-    }
-
-    surface = rsvg_cairo_surface_from_pixbuf (pixbuf);
-    if (!surface) {
-        g_set_error (error, RSVG_ERROR, RSVG_ERROR_FAILED, "could not convert pixbuf to cairo surface");
-        goto out;
-    }
-
-    if (mime_type == NULL) {
-        /* Try to get the information from the loader */
-        GdkPixbufFormat *format;
-        char **mime_types;
-
-        if ((format = gdk_pixbuf_loader_get_format (loader)) != NULL) {
-            mime_types = gdk_pixbuf_format_get_mime_types (format);
-
-            if (mime_types != NULL)
-                mime_type = g_strdup (mime_types[0]);
-            g_strfreev (mime_types);
-        }
-    }
-
-    if ((handle->priv->flags & RSVG_HANDLE_FLAG_KEEP_IMAGE_DATA) != 0 &&
-        mime_type != NULL &&
-        cairo_surface_set_mime_data (surface, mime_type, (guchar *) data,
-                                     data_len, g_free, data) == CAIRO_STATUS_SUCCESS) {
-        data = NULL; /* transferred to the surface */
-    }
-
-  out:
-    if (loader)
-        g_object_unref (loader);
-    g_free (mime_type);
-    g_free (data);
-
-    return surface;
-}
-
 #ifdef HAVE_PANGOFT2
 
 static void
