@@ -200,7 +200,8 @@ impl Parse for AspectRatio {
                 p.expect_ident()
                     .map_err(|_| ValueErrorKind::Parse(ParseError::new("expected identifier")))
                     .and_then(|ident| parse_fit_mode(ident))
-            }).unwrap_or(FitMode::default());
+            })
+            .unwrap_or(FitMode::default());
 
         parser
             .expect_exhausted()
